summaryrefslogtreecommitdiffstats
path: root/base/i18n/icu_util.cc
diff options
context:
space:
mode:
authorjeremy@chromium.org <jeremy@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-01-19 10:55:58 +0000
committerjeremy@chromium.org <jeremy@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-01-19 10:55:58 +0000
commitb0a28ee99b0d3b7c237f449824ad695a61bec37b (patch)
tree63ee34dce4291ed9313e8806ce9afbd5f226852d /base/i18n/icu_util.cc
parenta6ec730208e3704030f0d26afa6a7351e1b54425 (diff)
downloadchromium_src-b0a28ee99b0d3b7c237f449824ad695a61bec37b.zip
chromium_src-b0a28ee99b0d3b7c237f449824ad695a61bec37b.tar.gz
chromium_src-b0a28ee99b0d3b7c237f449824ad695a61bec37b.tar.bz2
Transition to base/mac/bundle_locations.h step 1
Initial transition steps, trying to do this in small steps so it's easier to review. foundation_util.h: * Remove SetOverride*() methods and modify all callsites to use bundle_location.h version. * MainAppBundle() - call through to bundle_location version as an interim step. * Rename PathForFrameworkBundleResource() and modify callers. * Remove one instance of [NSBundle mainBundle]. BUG=None TEST=Chrome/Mac should launch correctly and all unit tests should pass. Review URL: http://codereview.chromium.org/9187053 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@118284 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'base/i18n/icu_util.cc')
-rw-r--r--base/i18n/icu_util.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/base/i18n/icu_util.cc b/base/i18n/icu_util.cc
index e5bbe17..5b6a580 100644
--- a/base/i18n/icu_util.cc
+++ b/base/i18n/icu_util.cc
@@ -1,4 +1,4 @@
-// Copyright (c) 2009 The Chromium Authors. All rights reserved.
+// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -109,9 +109,9 @@ bool Initialize() {
// be released.
static file_util::MemoryMappedFile mapped_file;
if (!mapped_file.IsValid()) {
// Assume it is in the MainBundle's Resources directory.
FilePath data_path =
- base::mac::PathForMainAppBundleResource(CFSTR(ICU_UTIL_DATA_FILE_NAME));
+ base::mac::PathForFrameworkBundleResource(CFSTR(ICU_UTIL_DATA_FILE_NAME));
if (data_path.empty()) {
DLOG(ERROR) << ICU_UTIL_DATA_FILE_NAME << " not found in bundle";
return false;
@@ -109,9 +109,9 @@ bool Initialize() {
static file_util::MemoryMappedFile mapped_file;
if (!mapped_file.IsValid()) {
- // Assume it is in the MainBundle's Resources directory.
+ // Assume it is in the framework bundle's Resources directory.
FilePath data_path =